@@ -120,9 +120,10 @@ trash_applet_monitor_changed (TrashApplet *applet)
         {
           char *text;
 
-          text = g_strdup_printf (ngettext ("%d Item in Trash",
-                                            "%d Items in Trash",
-                                            items), items);
+          text = g_strdup_printf (dngettext (GETTEXT_PACKAGE,
+                                             "%d Item in Trash",
+                                             "%d Items in Trash",
+                                             items), items);
           gtk_widget_set_tooltip_text (GTK_WIDGET (applet), text);
           g_free (text);
         }
@@ -181,6 +182,51 @@ trash_applet_size_allocate (GtkWidget    *widget,
     ->size_allocate (widget, allocation);
 }
 
+static void
+trash_applet_setup (TrashApplet *self)
+{
+  const GtkTargetEntry drop_types[] = { { (char *) "text/uri-list" } };
+  const gchar *resource_name;
+
+  /* needed to clamp ourselves to the panel size */
+  gp_applet_set_flags (GP_APPLET (self), GP_APPLET_FLAGS_EXPAND_MINOR);
+
+  /* Set up the menu */
+  resource_name = GRESOURCE_PREFIX "/ui/trash-menu.ui";
+  gp_applet_setup_menu_from_resource (GP_APPLET (self),
+                                      resource_name,
+                                      trash_applet_menu_actions);
+
+  /* setup the image */
+  self->image = g_object_ref_sink (gtk_image_new ());
+  gtk_container_add (GTK_CONTAINER (self), self->image);
+  gtk_widget_show (self->image);
+
+  /* setup the trash backend */
+  self->trash = g_file_new_for_uri ("trash:/");
+  self->trash_monitor = g_file_monitor_file (self->trash, 0, NULL, NULL);
+  g_file_monitor_set_rate_limit (self->trash_monitor, 200);
+  g_signal_connect_swapped (self->trash_monitor, "changed",
+                            G_CALLBACK (trash_applet_monitor_changed),
+                            self);
+
+  /* setup drag and drop */
+  gtk_drag_dest_set (GTK_WIDGET (self), GTK_DEST_DEFAULT_ALL,
+                     drop_types, G_N_ELEMENTS (drop_types),
+                     GDK_ACTION_MOVE);
+
+  /* synthesise the first update */
+  self->items = -1;
+  trash_applet_monitor_changed (self);
+}
+
+static void
+trash_applet_constructed (GObject *object)
+{
+  G_OBJECT_CLASS (trash_applet_parent_class)->constructed (object);
+  trash_applet_setup (TRASH_APPLET (object));
+}
+
 static void
 trash_applet_dispose (GObject *object)
 {
@@ -388,16 +434,18 @@ confirm_delete_immediately (GtkWidget *parent_view,
   if (all)
     {
       prompt = _("Cannot move items to trash, do you want to delete them immediately?");
-      detail = g_strdup_printf (ngettext ("The selected item cannot be moved to the trash",
-                                          "None of the %d selected items can be moved to the Trash",
-                                          num_files), num_files);
+      detail = g_strdup_printf (dngettext (GETTEXT_PACKAGE,
+                                           "The selected item cannot be moved to the trash",
+                                           "None of the %d selected items can be moved to the Trash",
+                                           num_files), num_files);
     }
   else
     {
       prompt = _("Cannot move some items to trash, do you want to delete these immediately?");
-      detail = g_strdup_printf (ngettext ("The selected item cannot be moved to the Trash",
-                                          "%d of the selected items cannot be moved to the Trash",
-                                          num_files) , num_files);
+      detail = g_strdup_printf (dngettext (GETTEXT_PACKAGE,
+                                           "The selected item cannot be moved to the Trash",
+                                           "%d of the selected items cannot be moved to the Trash",
+                                           num_files) , num_files);
     }
 
   str = g_strconcat ("<span weight=\"bold\" size=\"larger\">",
@@ -507,6 +555,7 @@ trash_applet_class_init (TrashAppletClass *self_class)
   object_class = G_OBJECT_CLASS (self_class);
   widget_class = GTK_WIDGET_CLASS (self_class);
 
+  object_class->constructed = trash_applet_constructed;
   object_class->dispose = trash_applet_dispose;
 
   widget_class->size_allocate = trash_applet_size_allocate;
@@ -519,39 +568,6 @@ trash_applet_class_init (TrashAppletClass *self_class)
 static void
 trash_applet_init (TrashApplet *self)
 {
-  const GtkTargetEntry drop_types[] = { { (char *) "text/uri-list" } };
-  const gchar *resource_name;
-
-  /* needed to clamp ourselves to the panel size */
-  gp_applet_set_flags (GP_APPLET (self), GP_APPLET_FLAGS_EXPAND_MINOR);
-
-  /* Set up the menu */
-  resource_name = GRESOURCE_PREFIX "/ui/trash-menu.ui";
-  gp_applet_setup_menu_from_resource (GP_APPLET (self),
-                                      resource_name,
-                                      trash_applet_menu_actions);
-
-  /* setup the image */
-  self->image = g_object_ref_sink (gtk_image_new ());
-  gtk_container_add (GTK_CONTAINER (self), self->image);
-  gtk_widget_show (self->image);
-
-  /* setup the trash backend */
-  self->trash = g_file_new_for_uri ("trash:/");
-  self->trash_monitor = g_file_monitor_file (self->trash, 0, NULL, NULL);
-  g_file_monitor_set_rate_limit (self->trash_monitor, 200);
-  g_signal_connect_swapped (self->trash_monitor, "changed",
-                            G_CALLBACK (trash_applet_monitor_changed),
-                            self);
-
-  /* setup drag and drop */
-  gtk_drag_dest_set (GTK_WIDGET (self), GTK_DEST_DEFAULT_ALL,
-                     drop_types, G_N_ELEMENTS (drop_types),
-                     GDK_ACTION_MOVE);
-
-  /* synthesise the first update */
-  self->items = -1;
-  trash_applet_monitor_changed (self);
 }
 
 void
